@@ -728,105 +728,6 @@ importSTATA <- function() {
 # The following function was contributed by Matthieu Lesnoff 
 #  (added with small changes by J. Fox, 20 July 06)
 
-importRODBCtable <- function(){
-    # load the RODBC package and stops the program if not available
-    if(!require(RODBC))
-        stop(gettextRcmdr("This function requires the RODBC package.\n"))
-    # close all databases in case of error
-    on.exit(odbcCloseAll())
-# Enter the name of data set, by default : Dataset    
-    initializeDialog(title = gettextRcmdr("Import from Excel, Access or dBase data set"))
-    dsname <- tclVar(gettextRcmdr("Dataset"))
-    entryDsname <- tkentry(top, width = "35", textvariable = dsname)
-      onOK <- function(){
-        closeDialog()
-        dsnameValue <- trim.blanks(tclvalue(dsname))
-        if(dsnameValue == ""){
-            errorCondition(recall = importRODBCtable,
-                message = gettextRcmdr("You must enter the name of a data set."))
-            return()
-            }     
-        if(!is.valid.name(dsnameValue)){
-            errorCondition(recall = queryimportRODBCtable,
-                message = paste('"', dsnameValue, '" ', 
-                    gettextRcmdr("is not a valid name."), sep = ""))
-            return()
-            }
-        if(is.element(dsnameValue, listDataSets())){
-            if("no" == tclvalue(checkReplace(dsnameValue, gettextRcmdr("Data set")))){
-                importRODBCtable()
-                return()
-                }
-            }                              
-        File <- tclvalue(tkgetOpenFile(filetypes = gettextRcmdr(
-            '{"MS Excel file" {*.xls ".XLS"}} {"MS Access database" {*.mdb ".MDB"}} {"dBase-like file" {*.dbf ".DBF"}} {"All Files" {"*"}}'
-            )))                
-        if(File == ""){
-            tkfocus(CommanderWindow())
-            return()
-            }              
-        sop <- match(".", rev(strsplit(File, NULL)[[1]]))[1]
-        ext <- tolower(substring(File, nchar(File) - sop + 2, nchar(File)))
-        channel <- switch(EXPR = ext,
-            xls = odbcConnectExcel(File),
-            mdb = odbcConnectAccess(File),
-            dbf = odbcConnectDbase(File))        
-    # For Excel and Access cases, need to select a particular sheet or table
-        if(ext != "dbf"){
-            tabdat <- sqlTables(channel)
-            names(tabdat) <- tolower(names(tabdat))
-            if(ext == "mdb")
-                tabdat <- tabdat[tabdat$table_type == "TABLE", 3]
-            if(ext == "xls"){
-                tabname <- tabdat$table_name
-                tabdat <- ifelse(tabdat$table_type =="TABLE",
-                substring(tabname, 2, nchar(tabname) - 2),
-                substring(tabname, 1, nchar(tabname) - 1))
-                }      
-    # if there are several tables   
-          if(length(tabdat)>1)
-                fil <- tk_select.list(sort(tabdat), 
-                    title = gettextRcmdr("Select one table"))    
-          else  
-            fil <- tabdat               
-          if(fil == ""){
-            errorCondition(message=gettextRcmdr("No table selected"))
-            return()
-            }               
-          if(ext == "xls")
-            fil <- paste("[", fil, "$]", sep = "")
-          }            
-    # dBase file
-        else{
-          sop <- match(".", rev(strsplit(File, NULL)[[1]]))[1]
-          root <- tolower(substring(File, 1, nchar(File) - sop))
-          revstr <- rev(strsplit(root, NULL)[[1]])
-          sop <- if(is.na(match(c("/", "\\"), revstr)[1])) 
-            length(revstr) else match(c("/", "\\"), revstr)[1] - 1
-          toor <- revstr[seq(sop)]
-          fil <- paste(rev(toor), collapse = "")
-          }        
-    # Retrieve the data
-        dat <- sqlQuery(channel = channel, query = paste("select * from", fil))
-        names(dat)<- trim.blanks(names(dat))
-        dat <- trim.col.na(dat)        
-        odbcCloseAll()
-        assign(dsnameValue, as.data.frame(dat), envir = .GlobalEnv)
-        command <- paste("sqlQuery(channel = ",channel,", select * from ", fil,")", 
-            sep = "")
-        logger(paste(dsnameValue, " <- ", command, sep = ""))                
-        activeDataSet(dsnameValue)
-        tkfocus(CommanderWindow())              
-        }  ## End of function onOK       
-    OKCancelHelp(helpSubject="odbcConnect")
-    tkgrid(tklabel(top, text=gettextRcmdr("Enter name of data set:  ")), 
-        entryDsname, sticky="e")
-    tkgrid(buttonsFrame, columnspan="2", sticky="w")
-    tkgrid.configure(entryDsname, sticky="w")
-    dialogSuffix(rows=2, columns=2, focus=entryDsname)
-    }
-
-
 numericToFactor <- function(){
     initializeDialog(title=gettextRcmdr("Convert Numeric Variables to Factors"))
     variableBox <- variableListBox(top, Numeric(), selectmode="multiple", 
