@@ -658,151 +658,6 @@ PlotMeans <- function(){
     dialogSuffix(rows=3, columns=2)
     }
 
-Scatter3D <- function(){
-    use.rgl <- options("Rcmdr")[[1]]$use.rgl
-    if (length(use.rgl) == 0 || use.rgl) {
-        require(rgl)
-        require(mgcv)
-        }    
-    initializeDialog(title=gettextRcmdr("3D Scatterplot"))
-    variablesFrame <- tkframe(top)
-    .numeric <- Numeric()
-    xBox <- variableListBox(variablesFrame, .numeric, title=gettextRcmdr("Explanatory variables (pick two)"), selectmode="multiple",
-        initialSelection=NULL)
-    yBox <- variableListBox(variablesFrame, .numeric, title=gettextRcmdr("Response variable (pick one)"))
-    surfacesFrame <- tkframe(top)
-    identifyPoints <- tclVar("0") 
-    identifyPointsCheckBox <- tkcheckbutton(surfacesFrame, variable=identifyPoints)
-    axisScales <- tclVar("1")
-    axisScalesCheckBox <- tkcheckbutton(surfacesFrame, variable=axisScales)
-    gridLines <- tclVar("1")
-    gridLinesCheckBox <- tkcheckbutton(surfacesFrame, variable=gridLines)
-    squaredResiduals <- tclVar("0")
-    squaredResidualsCheckBox <- tkcheckbutton(surfacesFrame, variable=squaredResiduals)
-    linearLSSurface <- tclVar("1")
-    linearLSCheckBox <- tkcheckbutton(surfacesFrame, variable=linearLSSurface)
-    quadLSSurface <- tclVar("0")
-    quadLSCheckBox <- tkcheckbutton(surfacesFrame, variable=quadLSSurface)
-    nonparSurface <- tclVar("0")
-    nonparCheckBox <- tkcheckbutton(surfacesFrame, variable=nonparSurface)
-    dfNonparVariable <- tclVar(gettextRcmdr("<auto>"))
-    dfNonparField <- tkentry(surfacesFrame, width="6", textvariable=dfNonparVariable)
-    additiveSurface <- tclVar("0")
-    additiveCheckBox <- tkcheckbutton(surfacesFrame, variable=additiveSurface)
-    dfAddVariable <- tclVar(gettextRcmdr("<auto>"))
-    dfAddField <- tkentry(surfacesFrame, width="6", textvariable=dfAddVariable)
-    ellipsoid <- tclVar("0")
-    ellipsoidCheckBox <- tkcheckbutton(surfacesFrame, variable=ellipsoid)
-    bgFrame <- tkframe(top)
-    bgVariable <-tclVar("white")
-    whiteButton <- tkradiobutton(bgFrame, variable=bgVariable, value="white")
-    blackButton <- tkradiobutton(bgFrame, variable=bgVariable, value="black")
-    onOK <- function(){
-        x <- getSelection(xBox)
-        y <- getSelection(yBox)
-        closeDialog()
-        if (length(y) == 0) {
-            errorCondition(recall=Scatter3D, message=gettextRcmdr("You must select a response variable."))
-            return()
-            }
-        if (2 != length(x)) {
-            errorCondition(recall=Scatter3D, message=gettextRcmdr("You must select 2 explanatory variables."))
-            return()
-            }
-        if (is.element(y, x)) {
-            errorCondition(recall=Scatter3D, message=gettextRcmdr("Response and explanatory variables must be different."))
-            return()
-            }
-        scales <- if (tclvalue(axisScales) == 1) "TRUE" else "FALSE"
-        grid <- if (tclvalue(gridLines) == 1) "TRUE" else "FALSE"
-        resids <- if(tclvalue(squaredResiduals) == 1) ', residuals="squares"' else ", residuals=TRUE"
-        lin <- if(tclvalue(linearLSSurface) == 1) '"linear"'
-        quad <- if(tclvalue(quadLSSurface) == 1) '"quadratic"'
-        nonpar <- if (tclvalue(nonparSurface) == 1) '"smooth"'
-        additive <- if (tclvalue(additiveSurface) == 1) '"additive"'
-        surfaces <- c(lin, quad, nonpar, additive)
-        nsurfaces <- length(surfaces)
-        if (nsurfaces > 1) resids <- ""
-        ellips <- if(tclvalue(ellipsoid) == 1) "TRUE" else "FALSE"
-        opts <- options(warn=-1)
-        dfNonpar <- tclvalue(dfNonparVariable)
-        dfNonpar <- if (dfNonpar == gettextRcmdr("<auto>")) "" else paste(", df.smooth=", as.numeric(dfNonpar), sep="")
-        dfAdd <- tclvalue(dfAddVariable)
-        dfAdd <- if (dfAdd == gettextRcmdr("<auto>")) "" else paste(", df.additive=", as.numeric(dfAdd), sep="")
-        options(opts)
-        fit <- if (nsurfaces == 0) ", surface=FALSE"
-            else if (nsurfaces == 1) paste(", fit=", surfaces, sep="")
-            else paste(", fit=c(", paste(surfaces, collapse=","), ")", sep="")
-        bg <- tclvalue(bgVariable)
-        .activeDataSet <- ActiveDataSet()
-        if (.groups != FALSE){ 
-            groups <- paste(", groups=", .activeDataSet, "$", .groups, sep="")
-            parallel <- paste(", parallel=", .linesByGroup, sep="")
-            }
-        else groups <- parallel <- ""                   
-        command <- paste("scatter3d(", .activeDataSet, "$", x[1], ", ", 
-            .activeDataSet, "$", y, ", ", .activeDataSet, "$", x[2], fit, resids, dfNonpar, 
-            dfAdd, groups, parallel, ', bg="', bg, '", axis.scales=', scales, ', grid=', grid,
-            ', ellipsoid=', ellips, ', xlab="', x[1], '", ylab="', y, '", zlab="', x[2], '")', sep="")
-        doItAndPrint(command)
-        putRcmdr("rgl", TRUE)
-        command <- paste("identify3d(", .activeDataSet, "$", x[1], ", ", 
-            .activeDataSet, "$", y, ", ", .activeDataSet, "$", x[2], groups,
-            ', axis.scales=', scales, 
-            ", labels=row.names(", .activeDataSet, "))", sep="")
-        putRcmdr("Identify3d", command)
-        .Tcl("update")
-        if (tclvalue(identifyPoints) == 1){ 
-            RcmdrTkmessageBox(title="Identify Points",
-                message=gettextRcmdr("Drag right mouse button to identify points,\nclick right button to exit."),
-                icon="info", type="ok") 
-            doItAndPrint(command)
-            }
-        activateMenus()
-        tkfocus(CommanderWindow())
-        rgl.bringtotop()
-        }
-    groupsBox(Scatter3D, plotLinesByGroup=TRUE, plotLinesByGroupsText=gettextRcmdr("Parallel regression surfaces"))
-    OKCancelHelp(helpSubject="Scatter3DDialog")
-    tkgrid(getFrame(yBox), tklabel(variablesFrame, text="  "), getFrame(xBox), sticky="nw")
-    tkgrid(variablesFrame, sticky="nw")
-    tkgrid(tklabel(surfacesFrame, text=gettextRcmdr("Identify observations\nwith mouse")), identifyPointsCheckBox, sticky="w")
-    tkgrid(tklabel(surfacesFrame, text=gettextRcmdr("Show axis scales")), axisScalesCheckBox, sticky="w")
-    tkgrid(tklabel(surfacesFrame, text=gettextRcmdr("Show surface grid lines")), gridLinesCheckBox, sticky="w")
-    tkgrid(tklabel(surfacesFrame, text=gettextRcmdr("Show squared residuals")), squaredResidualsCheckBox, sticky="w")
-    tkgrid(tklabel(surfacesFrame, text=gettextRcmdr("Surfaces to Fit"), fg="blue"), sticky="w")
-    tkgrid(tklabel(surfacesFrame, text=gettextRcmdr("Linear least-squares")), linearLSCheckBox, sticky="w")
-    tkgrid(tklabel(surfacesFrame, text=gettextRcmdr("Quadratic least-squares")), quadLSCheckBox, sticky="w")
-    dfLabel <- tklabel(surfacesFrame, text=gettextRcmdr("df = "))
-    tkgrid(tklabel(surfacesFrame, text=gettextRcmdr("Smooth regression")), nonparCheckBox, 
-        dfLabel, dfNonparField, sticky="w")
-    tkgrid.configure(dfLabel, sticky="e")
-    tkgrid(tklabel(surfacesFrame, text=gettextRcmdr("Additive regression")), additiveCheckBox, 
-        tklabel(surfacesFrame, text=gettextRcmdr("df(each term) = ")), dfAddField, sticky="w")
-    tkgrid(tklabel(surfacesFrame, text=gettextRcmdr("Plot 50% concentration ellipsoid")), ellipsoidCheckBox, sticky="w")
-    tkgrid(surfacesFrame, sticky="w") 
-    tkgrid(tklabel(bgFrame, text=gettextRcmdr("Background Color"), fg="blue"), sticky="w", columnspan=2)
-    tkgrid(tklabel(bgFrame, text=gettextRcmdr("Black")), blackButton, sticky="w")
-    tkgrid(tklabel(bgFrame, text=gettextRcmdr("White")), whiteButton, sticky="w")
-    tkgrid(bgFrame, sticky="w")
-    tkgrid(groupsFrame, sticky="w")
-    tkgrid(buttonsFrame, stick="w")
-    dialogSuffix(rows=5, columns=1)
-    }
-
-Identify3D <- function(){
-    if (0 == rgl.cur()) {
-        Message(message=gettextRcmdr("There is no current RGL graphics device."),
-            type="error")
-        return()
-        }
-    RcmdrTkmessageBox(title="Identify Points",
-        message=gettextRcmdr("Drag right mouse button to identify points,\nclick right button to exit."),
-        icon="info", type="ok") 
-    command <- getRcmdr("Identify3d")
-    doItAndPrint(command)
-    }
-    
 saveBitmap <- function(){
     if (1 == dev.cur()) {
         Message(gettextRcmdr("There is no current graphics device to save."), type="error")
@@ -921,98 +776,4 @@ saveRglGraph <- function(){
     Message(paste(gettextRcmdr("Graph saved to file"), filename), type="note")
     }
     
-# The following function by Richard Heiberger, with small modifications by J. Fox
-
-Xyplot <- function() {
-    require("lattice")
-    initializeDialog(title=gettextRcmdr("XY Conditioning Plot"))
-    predictorBox <- variableListBox(top, Numeric(), title=gettextRcmdr("Explanatory variables (pick one or more)"), selectmode="multiple")
-    responseBox <- variableListBox(top, Numeric(), title=gettextRcmdr("Response variables (pick one or more)"), selectmode="multiple")
-    groupsBox <- variableListBox(top, Factors(), title=gettextRcmdr("Groups (pick zero or more)"), selectmode="multiple", initialSelection=FALSE)
-    checkBoxes(frame="optionsFrame",
-               boxes=c("auto.key", "outer"),
-               initialValues=c(1,0),
-               labels=gettextRcmdr(c("Automatically draw key", 
-                "Different panels for different responses")))
-    radioButtons(name="x.relation",
-                 buttons=c("same", "free", "sliced"),
-                 labels=gettextRcmdr(c("Identical", "Free", "Same range")),
-                 title=gettextRcmdr("X-Axis Scales in Different Panels"))
-    radioButtons(name="y.relation",
-                 buttons=c("same", "free", "sliced"),
-                 labels=gettextRcmdr(c("Identical", "Free", "Same range")),
-                 title=gettextRcmdr("Y-Axis Scales in Different Panels"))
-    onOK <- function() {
-        predictor <- getSelection(predictorBox)
-        response <- getSelection(responseBox)
-        groups <- getSelection(groupsBox)
-        closeDialog()
-        if (0 == length(response)) {
-            errorCondition(recall=Xyplot, message=gettextRcmdr("At least one response variable must be selected."))
-            return()
-            }
-        if (0 == length(predictor)) {
-            errorCondition(recall=Xyplot, message=gettextRcmdr("At least one explanatory variable must be selected."))
-            return()
-            }
-        auto.key <- ("1" == tclvalue(auto.keyVariable))
-        outer    <- ("1" == tclvalue(outerVariable))
-        x.relation <- as.character(tclvalue(x.relationVariable))
-        y.relation <- as.character(tclvalue(y.relationVariable))
-        .activeDataSet <- ActiveDataSet()
-        xyplot.command <- paste("xyplot(",
-                                paste(response, collapse=' + '),
-                                " ~ ",
-                                paste(predictor, collapse=' + '),
-                                if (length(groups) > 0)
-                                   paste(" | ",
-                                         paste(groups, collapse=' + ')
-                                         ) else "",
-                                if (outer) ", outer=TRUE",
-                                if (length(groups)==0) {
-                                  if (outer) paste(", layout=c(",
-                                                   length(predictor),
-                                                   ",",
-                                                   length(response),
-                                                   ")")
-                                }
-                                else {  ## (length(groups)>0)
-                                  if (outer) {
-                                    group.levels <- prod(sapply(groups, d.f=get(.activeDataSet),
-                                                                function(g, d.f) length(levels(d.f[[g]]))))
-                                    paste(", layout=c(",
-                                          group.levels,
-                                          "*",
-                                          length(predictor),
-                                          ",",
-                                          length(response),
-                                          ")",
-                                          ## ", between=list(x=c(0,0, 1, 0,0), y=1)",
-                                          ", between=list(x=c(",
-                                          paste(rep(c(rep(0, group.levels-1), 1),
-                                                    length=group.levels*length(predictor)-1),
-                                                collapse=","),
-                                          "), y=1)")
-                                  }
-                                },
-                                if (auto.key) ", auto.key=TRUE" else "",
-                                paste(", scales=list(x=list(relation='",
-                                      x.relation,
-                                      "'), y=list(relation='",
-                                      y.relation,
-                                      "'))", sep=""),
-                                ", data=", .activeDataSet, ')', sep="")
-        doItAndPrint(xyplot.command)
-        activateMenus()
-        tkfocus(CommanderWindow())
-        }
-    OKCancelHelp(helpSubject="xyplot")
-    tkgrid(getFrame(predictorBox), getFrame(responseBox), sticky="nw")
-    tkgrid(getFrame(groupsBox), sticky="w")
-    tkgrid(optionsFrame, sticky="w")
-    tkgrid(x.relationFrame, sticky="w")
-    tkgrid(y.relationFrame, sticky="w")
-    tkgrid(buttonsFrame, columnspan=2, sticky="w")
-    dialogSuffix(rows=6, columns=2)
-    }
 
